@@ -1,12 +1,10 @@
-context("AutoTuner")
-
 test_that("AutoTuner / train+predict", {
   te = trm("evals", n_evals = 4)
   task = tsk("iris")
   ps = TEST_MAKE_PS1(n_dim = 1)
   ms = MeasureDummyCPClassif$new(fun = function(pv) if (pv$cp == 0.2) 0 else 1) # lets fake a measure, so we control the best config
   tuner = tnr("grid_search", resolution = 3)
-  at = AutoTuner$new(lrn("classif.rpart"), rsmp("holdout"), ms, ps, te, tuner = tuner)
+  at = AutoTuner$new(lrn("classif.rpart"), rsmp("holdout"), ms, te, tuner = tuner, ps)
   expect_learner(at)
   at$train(task)
   expect_learner(at)
@@ -19,7 +17,7 @@ test_that("AutoTuner / train+predict", {
   expect_equal(r$learner_param_vals[[1]], list(xval = 0, cp = 0.2))
   prd = at$predict(task)
   expect_prediction(prd)
-  expect_is(at$learner$model, "rpart")
+  expect_s3_class(at$learner$model, "rpart")
 })
 
 test_that("AutoTuner / resample", {
@@ -34,7 +32,7 @@ test_that("AutoTuner / resample", {
   param_set = TEST_MAKE_PS1()
   te = trm("evals", n_evals = inner_evals)
   tuner = tnr("grid_search", resolution = 3)
-  at = AutoTuner$new(lrn("classif.rpart", predict_type = "prob"), r_inner, ms, param_set, te, tuner)
+  at = AutoTuner$new(lrn("classif.rpart", predict_type = "prob"), r_inner, ms, te, tuner, param_set)
 
   expect_null(at$tuning_instance)
   expect_equal(at$predict_type, "prob")
@@ -53,36 +51,6 @@ test_that("AutoTuner / resample", {
   })
 })
 
-# we had an issue that the AutoTuner did not return statically configured param in its result
-# see issue #51
-test_that("AutoTuner / param_set", {
-  measure = msr("classif.ce")
-  te = trm("evals", n_evals = 3)
-  task = tsk("iris")
-  ps = TEST_MAKE_PS1()
-  tuner = TunerRandomSearch$new()
-  learner = lrn("classif.rpart", cp = 1, maxdepth = 1)
-  at = AutoTuner$new(learner, rsmp("holdout"), measure, ps, te, tuner)
-  expect_equal(at$param_set$values[names(at$learner$param_set$values)], at$learner$param_set$values)
-  at$train(task)
-
-  # parameter that is not in training ps was used
-  expect_equal(at$param_set$values$maxdepth, 1)
-  expect_equal(at$learner$param_set$values$maxdepth, 1)
-  expect_equal(at$learner$model$control$maxdepth, 1)
-  # parameter that *is* in training ps was changed (to inside training range)
-  expect_lt(at$learner$model$control$cp, ps$params$cp$upper)
-
-  expect_equal(at$param_set$values$maxdepth, 1)
-  # expect_equal(at$param_set$values$cp, 1)
-
-  # param set, including id, survives clone
-  at$param_set$set_id = "xyz"
-  at2 = at$clone(deep = TRUE)
-  expect_equal(at$param_set, at2$param_set)
-})
-
-
 test_that("Custom resampling is not allowed", {
   measure = msr("classif.ce")
   te = trm("evals", n_evals = 4)
@@ -90,11 +58,9 @@ test_that("Custom resampling is not allowed", {
   ps = TEST_MAKE_PS1()
   tuner = TunerRandomSearch$new()
   r = rsmp("holdout")$instantiate(task)
-  expect_error(AutoTuner$new(lrn("classif.rpart"), r, measure, ps, te, tuner), "instantiated")
+  expect_error(AutoTuner$new(lrn("classif.rpart"), r, measure, te, tuner, ps), "instantiated")
 })
 
-
-
 test_that("nested resamppling results are consistent ", {
   # we had a bad pointer bug due to missing cloning here
   # https://github.com/mlr-org/mlr3/issues/428
@@ -129,7 +95,7 @@ test_that("AT training does not change learner in instance args", {
   # https://github.com/mlr-org/mlr3/issues/428
   task = tsk("iris")
   ps = TEST_MAKE_PS1()
-  at = AutoTuner$new(lrn("classif.rpart"), rsmp("holdout"), msr("classif.ce"), ps, trm("evals", n_evals = 3), TunerRandomSearch$new())
+  at = AutoTuner$new(lrn("classif.rpart"), rsmp("holdout"), msr("classif.ce"), trm("evals", n_evals = 3), TunerRandomSearch$new(), ps)
   expect_equal(at$instance_args$learner$param_set$values, list(xval = 0))
   at$train(task)
   expect_equal(at$instance_args$learner$param_set$values, list(xval = 0))
@@ -169,7 +135,7 @@ test_that("AutoTuner works with graphlearner", {
   expect_equal(r$learner_param_vals[[1]]$classif.rpart.cp, 0.2)
   prd = at$predict(task)
   expect_prediction(prd)
-  expect_is(at$learner$model$classif.rpart$model, "rpart")
+  expect_s3_class(at$learner$model$classif.rpart$model, "rpart")
 })
 
 test_that("Nested resampling works with graphlearner", {
@@ -209,8 +175,8 @@ test_that("Nested resampling works with graphlearner", {
   expect_data_table(tab$learner[[1]]$archive$data(), nrows = 3L)
   expect_data_table(tab$learner[[2]]$archive$data(), nrows = 3L)
 
-  expect_is(tab$learner[[1]]$model$learner$model$classif.rpart$model, "rpart")
-  expect_is(tab$learner[[1]]$model$learner$model$classif.rpart$model, "rpart")
+  expect_s3_class(tab$learner[[1]]$model$learner$model$classif.rpart$model, "rpart")
+  expect_s3_class(tab$learner[[1]]$model$learner$model$classif.rpart$model, "rpart")
 })
 
 test_that("store_tuning_instance, store_benchmark_result and store_models flags work", {
@@ -220,8 +186,8 @@ test_that("store_tuning_instance, store_benchmark_result and store_models flags
   ms = msr("classif.ce")
   tuner = tnr("grid_search", resolution = 3)
 
-  at = AutoTuner$new(lrn("classif.rpart"), rsmp("holdout"), ms, ps, te,
-    tuner = tuner, store_tuning_instance = TRUE, store_benchmark_result = TRUE,
+  at = AutoTuner$new(lrn("classif.rpart"), rsmp("holdout"), ms, te,
+    tuner = tuner, ps, store_tuning_instance = TRUE, store_benchmark_result = TRUE,
     store_models = TRUE)
   at$train(task)
 
@@ -229,8 +195,8 @@ test_that("store_tuning_instance, store_benchmark_result and store_models flags
   assert_benchmark_result(at$tuning_instance$archive$benchmark_result)
   assert_class(at$tuning_instance$archive$benchmark_result$resample_result(1)$learners[[1]]$model, "rpart")
 
-  at = AutoTuner$new(lrn("classif.rpart"), rsmp("holdout"), ms, ps, te,
-    tuner = tuner, store_tuning_instance = TRUE, store_benchmark_result = TRUE,
+  at = AutoTuner$new(lrn("classif.rpart"), rsmp("holdout"), ms, te,
+    tuner = tuner, ps, store_tuning_instance = TRUE, store_benchmark_result = TRUE,
     store_models = FALSE)
   at$train(task)
 
@@ -238,36 +204,77 @@ test_that("store_tuning_instance, store_benchmark_result and store_models flags
   assert_benchmark_result(at$tuning_instance$archive$benchmark_result)
   assert_null(at$tuning_instance$archive$benchmark_result$resample_result(1)$learners[[1]]$model)
 
-  at = AutoTuner$new(lrn("classif.rpart"), rsmp("holdout"), ms, ps, te,
-    tuner = tuner, store_tuning_instance = TRUE, store_benchmark_result = FALSE,
+  at = AutoTuner$new(lrn("classif.rpart"), rsmp("holdout"), ms, te,
+    tuner = tuner, ps, store_tuning_instance = TRUE, store_benchmark_result = FALSE,
     store_models = FALSE)
   at$train(task)
 
   assert_r6(at$tuning_instance, "TuningInstanceSingleCrit")
   assert_null(at$tuning_instance$archive$benchmark_result)
 
-  at = AutoTuner$new(lrn("classif.rpart"), rsmp("holdout"), ms, ps, te,
-    tuner = tuner, store_tuning_instance = FALSE, store_benchmark_result = FALSE,
+  at = AutoTuner$new(lrn("classif.rpart"), rsmp("holdout"), ms, te,
+    tuner = tuner, ps, store_tuning_instance = FALSE, store_benchmark_result = FALSE,
     store_models = FALSE)
   at$train(task)
 
   assert_null(at$tuning_instance)
 
-  expect_error(AutoTuner$new(lrn("classif.rpart"), rsmp("holdout"), ms, ps, te,
-    tuner = tuner, store_tuning_instance = FALSE, store_benchmark_result = TRUE,
+  expect_error(AutoTuner$new(lrn("classif.rpart"), rsmp("holdout"), ms, te,
+    tuner = tuner, ps, store_tuning_instance = FALSE, store_benchmark_result = TRUE,
     store_models = FALSE),
     regexp = "Benchmark results can only be stored if store_tuning_instance is set to TRUE",
     fixed = TRUE)
 
-  expect_error(AutoTuner$new(lrn("classif.rpart"), rsmp("holdout"), ms, ps, te,
-    tuner = tuner, store_tuning_instance = TRUE, store_benchmark_result = FALSE,
+  expect_error(AutoTuner$new(lrn("classif.rpart"), rsmp("holdout"), ms, te,
+    tuner = tuner, ps, store_tuning_instance = TRUE, store_benchmark_result = FALSE,
     store_models = TRUE),
     regexp = "Models can only be stored if store_benchmark_result is set to TRUE",
     fixed = TRUE)
 
-  expect_error(AutoTuner$new(lrn("classif.rpart"), rsmp("holdout"), ms, ps, te,
-    tuner = tuner, store_tuning_instance = FALSE, store_benchmark_result = FALSE,
+  expect_error(AutoTuner$new(lrn("classif.rpart"), rsmp("holdout"), ms, te,
+    tuner = tuner, ps, store_tuning_instance = FALSE, store_benchmark_result = FALSE,
     store_models = TRUE),
     regexp = "Models can only be stored if store_benchmark_result is set to TRUE",
     fixed = TRUE)
 })
+
+test_that("predict_type works", {
+  te = trm("evals", n_evals = 4)
+  task = tsk("iris")
+  ps = TEST_MAKE_PS1(n_dim = 1)
+  ms = msr("classif.ce")
+  tuner = tnr("grid_search", resolution = 3)
+
+  at = AutoTuner$new(lrn("classif.rpart"), rsmp("holdout"), ms, te,
+    tuner = tuner, ps)
+
+  at$train(task)
+  expect_equal(at$predict_type, "response")
+  expect_equal(at$model$learner$predict_type, "response")
+
+  at$predict_type = "prob"
+  expect_equal(at$predict_type, "prob")
+  expect_equal(at$model$learner$predict_type, "prob")
+})
+
+test_that("search space from TuneToken works", {
+  learner = lrn("classif.rpart")
+  learner$param_set$values$cp = to_tune(0.1, 0.3)
+
+  at = AutoTuner$new(learner = learner, resampling = rsmp("holdout"),
+    measure = msr("classif.ce"), terminator = trm("evals", n_evals = 1),
+    tuner = tnr("random_search"))
+
+  at$train(tsk("iris"))
+  expect_equal(at$tuning_instance$search_space$ids(), "cp")
+
+  ps = ParamSet$new(list(
+    ParamDbl$new("cp", lower = 0.1, upper = 0.3)
+  ))
+
+  expect_error(AutoTuner$new(learner = learner, resampling = rsmp("holdout"),
+    measure = msr("classif.ce"), terminator = trm("evals", n_evals = 1),
+    tuner = tnr("random_search"), search_space = learner$param_set$search_space()),
+    regexp = "If the values of the ParamSet of the Learner contain TuneTokens you cannot supply a search_space.",
+    fixed = TRUE)
+})
