@@ -1,5 +1,3 @@
-context("TunerGenSA")
-
 skip_if_not_installed("GenSA")
 
 test_that("TunerGenSA", {
@@ -9,7 +7,7 @@ test_that("TunerGenSA", {
     ParamLgl$new("save_tasks")
   ))
   te = trm("evals", n_evals = 2)
-  inst = TuningInstanceSingleCrit$new(tsk("iris"), lrn("classif.debug"), rsmp("holdout"), msr("classif.ce"), ps, te)
+  inst = TuningInstanceSingleCrit$new(tsk("iris"), lrn("classif.debug"), rsmp("holdout"), msr("classif.ce"), te, ps)
   tt = TunerGenSA$new()
   expect_error(tt$optimize(inst), "support")
 })
@@ -24,7 +22,7 @@ test_that("TunerGenSA with int params and trafo", {
     return(x)
   }
   te = trm("evals", n_evals = 2)
-  inst = TuningInstanceSingleCrit$new(tsk("iris"), lrn("classif.rpart"), rsmp("holdout"), msr("classif.ce"), ps, te)
+  inst = TuningInstanceSingleCrit$new(tsk("iris"), lrn("classif.rpart"), rsmp("holdout"), msr("classif.ce"), te, ps)
   tt = TunerGenSA$new()
   tt$optimize(inst)
   d = inst$archive$data()
